@@ -2,12 +2,11 @@
 from __future__ import absolute_import
 
 import sys
-import warnings
 
 from pylint_django import plugin
 
 if sys.version_info < (3, ):
-    warnings.warn("Version 0.8.0 is the last to support Python 2. "
-                  "Please migrate to Python 3!", DeprecationWarning)
+    raise DeprecationWarning("Version 0.11.1 was the last to support Python 2. "
+                             "Please migrate to Python 3!")
 
 register = plugin.register  # pylint: disable=invalid-name
