@@ -432,7 +432,9 @@ def is_model_factory(node):
     except:  # noqa: E722, pylint: disable=bare-except
         return False
 
-    parents = ('factory.declarations.SubFactory', 'factory.django.DjangoModelFactory')
+    parents = ('factory.declarations.LazyFunction',
+               'factory.declarations.SubFactory',
+               'factory.django.DjangoModelFactory')
 
     for parent_class in parent_classes:
         try:
@@ -447,6 +449,23 @@ def is_model_factory(node):
     return False
 
 
+def is_factory_post_generation_method(node):
+    if not node.decorators:
+        return False
+
+    for decorator in node.decorators.get_children():
+        try:
+            inferred = decorator.inferred()
+        except InferenceError:
+            continue
+
+        for target in inferred:
+            if target.qname() == 'factory.helpers.post_generation':
+                return True
+
+    return False
+
+
 def is_model_mpttmeta_subclass(node):
     """Checks that node is derivative of MPTTMeta class."""
     if node.name != 'MPTTMeta' or not isinstance(node.parent, ClassDef):
@@ -488,6 +507,7 @@ def is_manager_attribute(node):
     """Checks that node is attribute of Manager or QuerySet class."""
     parents = ('django.db.models.manager.Manager',
                '.Manager',
+               'factory.base.BaseFactory.build',
                'django.db.models.query.QuerySet',
                '.QuerySet')
     return _attribute_is_magic(node, MANAGER_ATTRS.union(QS_ATTRS), parents)
@@ -728,6 +748,14 @@ def is_wsgi_application(node):
         (frame.name == 'wsgi' or frame.path[0].endswith('wsgi.py') or frame.file.endswith('wsgi.py'))
 
 
+# Compat helpers
+def pylint_newstyle_classdef_compat(linter, warning_name, augment):
+    if not hasattr(NewStyleConflictChecker, 'visit_classdef'):
+        return
+    suppress_message(linter, getattr(NewStyleConflictChecker, 'visit_classdef'), warning_name, augment)
+
+
+# augment things
 def apply_augmentations(linter):
     """Apply augmentation and suppression rules."""
     augment_visit(linter, TypeChecker.visit_attribute, foreign_key_sets)
@@ -762,15 +790,9 @@ def apply_augmentations(linter):
     # model forms have no __init__ method anywhere in their bases
     suppress_message(linter, ClassChecker.visit_classdef, 'W0232', is_class('django.forms.models.ModelForm'))
 
-    # forms implement __getitem__ but not __len__, thus raising a "Badly implemented container" warning which
-    # we will suppress. NOTE: removed from pylint, https://github.com/PyCQA/pylint/issues/112
-    # keeping here in case it gets re-implemented
-    # suppress_message(linter, _leave_classdef(MisdesignChecker), 'R0924', is_class('django.forms.forms.Form'))
-    # suppress_message(linter, _leave_classdef(MisdesignChecker), 'R0924', is_class('django.forms.models.ModelForm'))
-
     # Meta
     suppress_message(linter, DocStringChecker.visit_classdef, 'missing-docstring', is_model_meta_subclass)
-    suppress_message(linter, NewStyleConflictChecker.visit_classdef, 'old-style-class', is_model_meta_subclass)
+    pylint_newstyle_classdef_compat(linter, 'old-style-class', is_model_meta_subclass)
     suppress_message(linter, ClassChecker.visit_classdef, 'no-init', is_model_meta_subclass)
     suppress_message(linter, MisdesignChecker.leave_classdef, 'too-few-public-methods', is_model_meta_subclass)
     suppress_message(linter, ClassChecker.visit_attribute, 'protected-access', allow_meta_protected_access)
@@ -778,7 +800,7 @@ def apply_augmentations(linter):
     # Media
     suppress_message(linter, NameChecker.visit_assignname, 'C0103', is_model_media_valid_attributes)
     suppress_message(linter, DocStringChecker.visit_classdef, 'missing-docstring', is_model_media_subclass)
-    suppress_message(linter, NewStyleConflictChecker.visit_classdef, 'old-style-class', is_model_media_subclass)
+    pylint_newstyle_classdef_compat(linter, 'old-style-class', is_model_media_subclass)
     suppress_message(linter, ClassChecker.visit_classdef, 'no-init', is_model_media_subclass)
     suppress_message(linter, MisdesignChecker.leave_classdef, 'too-few-public-methods', is_model_media_subclass)
 
@@ -806,12 +828,13 @@ def apply_augmentations(linter):
 
     # django-mptt
     suppress_message(linter, DocStringChecker.visit_classdef, 'missing-docstring', is_model_mpttmeta_subclass)
-    suppress_message(linter, NewStyleConflictChecker.visit_classdef, 'old-style-class', is_model_mpttmeta_subclass)
+    pylint_newstyle_classdef_compat(linter, 'old-style-class', is_model_mpttmeta_subclass)
     suppress_message(linter, ClassChecker.visit_classdef, 'W0232', is_model_mpttmeta_subclass)
     suppress_message(linter, MisdesignChecker.leave_classdef, 'too-few-public-methods', is_model_mpttmeta_subclass)
 
     # factory_boy's DjangoModelFactory
     suppress_message(linter, TypeChecker.visit_attribute, 'no-member', is_model_factory)
+    suppress_message(linter, ClassChecker.visit_functiondef, 'no-self-argument', is_factory_post_generation_method)
 
     # ForeignKey and OneToOneField
     # Must update this in a thread safe way to support the parallel option on pylint (-j)
