@@ -15,7 +15,7 @@ class Author(models.Model):
 
 class Book(models.Model):
     title = models.CharField()
-    author = models.ForeignKey(Author, on_delete=models.CASCADE)
+    author = models.ForeignKey(Author, related_name='books', on_delete=models.CASCADE)
 
 
 class AuthorFactory(factory.django.DjangoModelFactory):
@@ -31,6 +31,7 @@ class BookFactory(factory.django.DjangoModelFactory):
 
     title = factory.Sequence(lambda n: 'Book %d' % n)
     author = factory.SubFactory(AuthorFactory)
+    reviewer = factory.LazyFunction(Author.objects.first())
 
 
 class BookTestCase(test.LiveServerTestCase):
@@ -39,6 +40,9 @@ class BookTestCase(test.LiveServerTestCase):
     def _fixture_setup(self):
         super(BookTestCase, self)._fixture_setup()
         self.book = BookFactory()
+        _author = AuthorFactory()
+        _first_book = _author.books.first()
+        self.assertIsNotNone(_first_book)
 
     def test_author_is_not_none(self):
         self.assertGreater(self.book.pk, 0)
@@ -46,3 +50,6 @@ class BookTestCase(test.LiveServerTestCase):
 
         self.assertIsNotNone(self.book.title)
         self.assertIsNotNone(self.book.author.name)
+
+    def test_reviewer_is_not_none(self):
+        self.assertGreater(self.book.reviewer.pk, 0)
